# Opinions

Opinions will generally be displayed on this website by 10 a.m. Pacific Time and Memorandum Dispositions by 1:00 p.m. Pacific Time on the day of filing. There is no charge to view or download these documents from our website. Please note that opinions and dispositions are also available from the PACER system shortly before they are posted to this site. PACER is a fee based system. Click here to open a PACER account and find out more about fees. PACER account holders may register as non-party users of the court's Appellate ECF system to obtain immediate email notification of the filing of opinions and dispositions in specific cases. Click here to register as a non-party user.

A note about our “Advanced Search” function. This is a powerful tool that can be used to search the entire database of opinions and display them by year, month, case type, case number and case name. You can also use the “Published Within” option to search based on date of publication. Use the "View" option to change the number of opinions displayed per page. Click the cells in the top row of the table to display opinions by case title, case number, case type, case code and date filed.

Please contact the clerk's office at 415-355-8000 for Published Opinions posted before January 3, 2005.
Ninth Circuit opinions (along with those of several other circuits) dating back to January 2008 are available for free with advanced search capabilities at the Government Printing Office's Federal Digital System here.

To automatically receive a free list of all opinions filed each day, select a type of feed from the menu below and subscribe to the court's daily opinions RSS feed. "By judge" feeds will show all opinions on which the named judge authored the opinion, a concurrence, or a dissent.

*: immediate filing o: order oa: order amending oad: order amended dissent oam: order and amended memorandum oap: order and amended opinion | oop: order & opinion o2: second opinion eb: en banc ebop: en banc opinion | ebo: en banc order cd: concurrence/dissent ad: amended dissent | s: supplemental opinion sd: supplemental dissent ao: amended opinion co: corrected opinion app: appendix

Published Within:

Search
by Case Title: |  |  |  |
by Case No.: |  |  |  |
by Case Origin: |  |  |  |
by Authoring Judge: |  |  |  |
by Concurring/Dissenting Judge: |  |  |  |
by Case Type: |  |  |  |
by Date Filed (mm/dd/yyyy): |  |  |  |
Search type:

Results: 1 - 50 of 7,283 |
Pages: |<< << | 1, 2, 3, 4, ... | >> >>|
| Page size:

loading data...

Case Title | Case No. | Case Origin | Authoring Judge | Case Type | Case Code | Date Filed
--- | --- | --- | --- | --- | --- | ---
TADEVOSYAN V. ERIC H. HOLDER, JR. | 07-75087 | Board of Immigration Appeals | BERZON, Marsha | Agency |  | 02/26/2014
CINDY GARCIA V. GOOGLE, INC. | 12-57302 | Los Angeles District Court | KOZINSKI, Alex | Civil |  | 02/26/2014
MARIA ESCRIBA V. FOSTER POULTRY FARMS, INC. | 11-17608 | Fresno District Court | Gilman, Ronald | Civil |  | 02/25/2014
HECTOR AYALA V. ROBERT WONG | 09-99005 | San Diego District Court | REINHARDT, Stephen | Prisoner Death Penalty |  | 02/25/2014
CRISANTO RAGASA V. ERIC HOLDER, JR. | 12-72262 | Board of Immigration Appeals |  | Agency | o* | 02/24/2014
KEVIN STOUT V. FREESCORE, LLC | 10-56887 | Los Angeles District Court | Cogan, Brian | Civil |  | 02/21/2014
TERESA SHEEHAN V. CITY AND COUNTY OF SAN FRANCIS | 11-16401 | San Francisco District Court | FISHER, Raymond | Civil |  | 02/21/2014
USA V. TAVARES CHANDLER | 12-10331 | Las Vegas District Court |  | Criminal |  | 02/20/2014
USA V. XOCHITL GARCIA-SANTANA | 12-10471 | Reno District Court | BERZON, Marsha | Criminal |  | 02/20/2014
ALETA LILLY V. CONAGRA FOODS, INC. | 12-55921 | Los Angeles District Court | SILVERMAN, Barry | Civil |  | 02/20/2014
NO OPINIONS FILED TODAY | 00-00000 |  |  |  |  | 02/19/2014
BLIXSETH v YELLOWSTONE MOUNTAIN CLUB | 12-35986 | District of Montana |  | Civil | * | 02/18/2014
USACM LIQUIDATING TRUST V. DELOITTE & TOUCHE, LLP | 11-15626 | Las Vegas District Court | Garbis, Marvin | Civil | oop | 02/18/2014
RAYMOND NAKANO V. USA | 11-18013 | Phoenix District Court | GRABER, Susan | Civil |  | 02/18/2014
WILLIAM THORNTON V. EDMUND G. BROWN, JR | 11-56146 | San Diego District Court | GRABER, Susan | Prisoner | oa | 02/18/2014
HONOLULUTRAFFIC.COM V. FTA | 13-15277 | Honolulu District Court | SCHROEDER, Mary | Civil |  | 02/18/2014
P. REA V. MICHAELS STORES INC | 14-55008 | Santa Ana District Court |  | Civil |  | 02/18/2014
MARY FRUDDEN V. KAYANN PILLING | 12-15403 | Reno District Court | NGUYEN, Jacqueline | Civil |  | 02/14/2014
USA V. ALVARO GONZALEZ-MONTERROSO | 12-10158 | Tucson District Court | IKUTA, Sandra | Criminal |  | 02/14/2014
LYDIA GARCIA-MILIAN V. ERIC HOLDER, JR. | 09-71461 | Board of Immigration Appeals | IKUTA, Sandra | Agency | oa | 02/13/2014
CLAUDE REESE V. ROBERT MALONE | 12-35260 | Seattle District Court | Dearie, Raymond | Civil |  | 02/13/2014
KELLY VOSGIEN V. ROB PERSSON | 12-35397 | Portland District Court | FLETCHER, William | Habeas |  | 02/13/2014
RETIRED EMPLOYEES ASSOCIATION V. COUNTY OF ORANGE | 12-56706 | Santa Ana District Court | McKEOWN, M. | Civil |  | 02/13/2014
EDWARD PERUTA V. COUNTY OF SAN DIEGO | 10-56971 | San Diego District Court | O'SCANNLAIN, Diarmuid | Civil |  | 02/13/2014
ROOSEVELT MOORE V. M. BITER | 11-56846 | Los Angeles District Court |  | Habeas | o | 02/12/2014
USA V. ALEXANDER POPOV | 12-10045 | Sacramento District Court | Lasnik, Robert | Criminal |  | 02/11/2014
USA V. DAMIEN ZEPEDA | 10-10131 | Phoenix District Court | KOZINSKI, Alex | Criminal | ebo* | 02/10/2014
KONOLUS SMITH V. GARRY SWARTHOUT | 11-17116 | Sacramento District Court | ALARCON, Arthur | Habeas |  | 02/10/2014
USA V. NICHOLAS VASQUEZ-PEREZ | 12-10433 | Tucson District Court | ALARCON, Arthur | Criminal |  | 02/10/2014
USA V. ERIC VALLEJOS | 13-10025 | Fresno District Court | GOULD, Ronald | Criminal |  | 02/10/2014
JUDITH ROMO V. TEVA PHARMACEUTICALS USA, INC. | 13-56310 | Los Angeles District Court | KOZINSKI, Alex | Civil | ebo | 02/10/2014
USA V. GREG CARTER | 12-10549 | Las Vegas District Court |  | Criminal |  | 02/07/2014
USA V. STEVEN HAMMOND | 12-30337 | Eugene District Court | Murphy, Stephen | Criminal |  | 02/07/2014
CHRISTOPHER BREWSTER V. NATIONSTAR MORTGAGE, LLC | 12-56560 | San Diego District Court | GOULD, Ronald | Civil |  | 02/07/2014
NO OPINIONS FILED TODAY | 00-00000 |  |  |  |  | 02/06/2014
ALEXANDER GRAHAM-SULT V. NICHOLAS CLAINOS | 11-16779 | Oakland District Court | SMITH, N.R. | Civil | oa | 02/05/2014
GREATER LOS ANGELES AGENCY ON V. CNN | 12-15807 | San Francisco District Court | McKEOWN, M. | Civil |  | 02/05/2014
USA V. KENYON LYLE, JR. | 12-30389 | Spokane District Court | BERZON, Marsha | Criminal |  | 02/05/2014
GREATER LOS ANGELES AGENCY ON V. CNN | 12-15807 | San Francisco District Court |  | Civil | o | 02/05/2014
CAROLINA CASUALTY INSURANCE CO V. TEAM EQUIPMENT, INC. | 12-56203 | Los Angeles District Court | CLIFTON, Richard | Civil |  | 02/04/2014
THOMAS ROBINS V. SPOKEO, INC. | 11-56843 | Los Angeles District Court | O'SCANNLAIN, Diarmuid | Civil |  | 02/04/2014
BENJAMIN BERGER V. HOME DEPOT U.S.A., INC. | 11-55592 | Santa Ana District Court | GOULD, Ronald | Civil |  | 02/03/2014
RICK CARTER V. CALEB BRETT LLC | 12-16846 | San Francisco District Court | ALARCON, Arthur | Civil |  | 02/03/2014
USA V. KENNETH WILLIAMS | 12-30353 | Spokane District Court | Rakoff, Jed | Criminal |  | 02/03/2014
WASHINGTON ENVIRONMENTAL COUNC V. THEODORE STURDEVANT | 12-35323 | Seattle District Court |  | Civil | o | 02/03/2014
C. B. V. CITY OF SONORA | 11-17454 | Fresno District Court | KOZINSKI, Alex | Civil | ebo | 02/03/2014
REPUBLIC OF ECUADOR V. DOUGLAS MACKAY | 12-15572 | Fresno District Court | CALLAHAN, Consuelo | Civil |  | 01/31/2014
NO OPINIONS FILED TODAY |  |  |  |  |  | 01/30/2014
BEEMAN V. ANTHEM PRESCRIPTION | 07-56692 | Riverside District Court |  | Civil | o | 01/29/2014
DAVID DEMERS V. ERICA AUSTIN | 11-35558 | Spokane District Court | FLETCHER, William | Civil | oop | 01/29/2014

Results: 1 - 50 of 7,283 |
Pages: |<< << | 1, 2, 3, 4, ... | >> >>|
| Page size:

- Electronic Filing - ECF
- Opinions
  - Published
  - Unpublished
- Calendar
  - Oral Arguments
  - Motions Panel
- Case Information
  - Dockets (PACER)
  - Pending En Banc Cases
- FAQs, Forms and
  Instructions
  - FAQs
  - After Opening a Case - Attorneys
  - After Opening a Case - Pro Se
  - Forms
  - Fee Schedule
  - Glossary
- Rules
  - FRAP & Circuit Rules
  - Streamlined Requests Replace Telephonic
    Requests for Extensions of Time
  - Electronic Submission of Excerpts
  - Proposed Rule Amendments
  - New and Amended 9th Circuit Rules
  - General Orders
- Guides and
  Legal Outlines
  - Appellate Jurisdiction in the Ninth Circuit
  - Appellate Practice Guide
  - How to File an Immigration Petition for Review
  - Ninth Circuit Immigration Outline
  - Perfecting Your Appeal
  - Section 1983 Outline
  - Social Security Outline
  - Standards of Review
- Audio and Video
- RSS Feeds

- Clerk's Office
- Mediation
- Appellate Commissioner
- Bankruptcy Appellate Panel

Welcome to the Internet portal of the United States Courts for the Ninth Circuit. more >> |  |
- Chief Judge Alex Kozinski

Site Map | Intranet (Judiciary Only) | COOP Staff Page | Seminar Disclosures | Judicial Misconduct |